@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -18,15 +18,21 @@
 */
 
 #include "sieveaction.h"
+#include "libksieve_debug.h"
 
 #include <KLocalizedString>
 
 #include <QWidget>
 
+#include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
+
 using namespace KSieveUi;
 
-SieveAction::SieveAction(const QString &name, const QString &label, QObject *parent)
-    : QObject(parent), mName(name), mLabel(label)
+SieveAction::SieveAction(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, const QString &name, const QString &label, QObject *parent)
+    : QObject(parent),
+      mSieveGraphicalModeWidget(sieveGraphicalModeWidget),
+      mName(name),
+      mLabel(label)
 {
 }
 
@@ -34,6 +40,24 @@ SieveAction::~SieveAction()
 {
 }
 
+KSieveUi::SieveImapAccountSettings SieveAction::sieveImapAccountSettings() const
+{
+    if (mSieveGraphicalModeWidget) {
+        return mSieveGraphicalModeWidget->sieveImapAccountSettings();
+    }
+    qCWarning(LIBKSIEVE_LOG) << "SieveAction::sieveImapAccountSettings Problem during initialize mSieveGraphicalModeWidget ";
+    return {};
+}
+
+QStringList SieveAction::sieveCapabilities() const
+{
+    if (mSieveGraphicalModeWidget) {
+        return mSieveGraphicalModeWidget->sieveCapabilities();
+    }
+    qCWarning(LIBKSIEVE_LOG) << "SieveAction::sieveCapabilities Problem during initialize mSieveGraphicalModeWidget ";
+    return {};
+}
+
 QString SieveAction::name() const
 {
     return mName;
@@ -44,11 +68,6 @@ QString SieveAction::label() const
     return mLabel;
 }
 
-SieveAction *SieveAction::newAction()
-{
-    return Q_NULLPTR;
-}
-
 QWidget *SieveAction::createParamWidget(QWidget *parent) const
 {
     return new QWidget(parent);
