@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,7 +25,7 @@
 #include "sieveactions/sieveactionlist.h"
 #include "commonwidgets/sievehelpbutton.h"
 #include "autocreatescriptutil_p.h"
-#include "PimCommon/MinimumComboBox"
+#include <PimCommon/MinimumComboBox>
 
 #include <QPushButton>
 #include <KLocalizedString>
@@ -51,8 +51,9 @@ inline const QString indentation()
 }
 }
 
-SieveActionWidget::SieveActionWidget(QWidget *parent)
-    : QWidget(parent)
+SieveActionWidget::SieveActionWidget(SieveEditorGraphicalModeWidget *graphicalModeWidget, QWidget *parent)
+    : QWidget(parent),
+      mSieveGraphicalModeWidget(graphicalModeWidget)
 {
     initWidget();
 }
@@ -88,7 +89,7 @@ void SieveActionWidget::generatedScript(QString &script, QStringList &requires,
         KSieveUi::SieveAction *widgetAction = mActionList.at(mComboBox->currentIndex());
         QWidget *currentWidget = mLayout->itemAtPosition(1, 3)->widget();
         const QStringList lstRequires = widgetAction->needRequires(currentWidget);
-        Q_FOREACH (const QString &r, lstRequires) {
+        for (const QString &r : lstRequires) {
             if (!requires.contains(r)) {
                 requires.append(r);
             }
@@ -108,11 +109,11 @@ void SieveActionWidget::initWidget()
 
     mComboBox = new PimCommon::MinimumComboBox;
     mComboBox->setEditable(false);
-    const QList<KSieveUi::SieveAction *> list = KSieveUi::SieveActionList::actionList();
+    const QList<KSieveUi::SieveAction *> list = KSieveUi::SieveActionList::actionList(mSieveGraphicalModeWidget);
     QList<KSieveUi::SieveAction *>::const_iterator it;
     QList<KSieveUi::SieveAction *>::const_iterator end(list.constEnd());
     int index = 0;
-    QStringList listCapabilities = SieveEditorGraphicalModeWidget::sieveCapabilities();
+    QStringList listCapabilities = mSieveGraphicalModeWidget->sieveCapabilities();
     //imapflags was old name of imap4flags but still used.
     if (listCapabilities.contains(QStringLiteral("imap4flags"))) {
         listCapabilities.append(QStringLiteral("imapflags"));
@@ -137,12 +138,12 @@ void SieveActionWidget::initWidget()
         }
     }
 
-    mHelpButton = new SieveHelpButton;
+    mHelpButton = new SieveHelpButton(this);
     mHelpButton->setEnabled(false);
     connect(mHelpButton, &SieveHelpButton::clicked, this, &SieveActionWidget::slotHelp);
     mLayout->addWidget(mHelpButton, 1, 0);
 
-    mCommentButton = new QToolButton;
+    mCommentButton = new QToolButton(this);
     mCommentButton->setToolTip(i18n("Add comment"));
     mCommentButton->setEnabled(false);
     mLayout->addWidget(mCommentButton, 1, 1);
@@ -177,7 +178,7 @@ void SieveActionWidget::initWidget()
 
     connect(mAdd, &QPushButton::clicked, this, &SieveActionWidget::slotAddWidget);
     connect(mRemove, &QPushButton::clicked, this, &SieveActionWidget::slotRemoveWidget);
-    setFilterAction(Q_NULLPTR);
+    setFilterAction(nullptr);
 }
 
 void SieveActionWidget::slotHelp()
@@ -221,7 +222,7 @@ void SieveActionWidget::slotActionChanged(int index)
     } else {
         mAdd->setEnabled(true);
         mCommentButton->setEnabled(false);
-        setFilterAction(Q_NULLPTR);
+        setFilterAction(nullptr);
         mHelpButton->setEnabled(false);
     }
     Q_EMIT valueChanged();
@@ -259,8 +260,9 @@ bool SieveActionWidget::setAction(const QString &actionName, const QDomElement &
     return result;
 }
 
-SieveActionWidgetLister::SieveActionWidgetLister(QWidget *parent)
-    : KPIM::KWidgetLister(false, MINIMUMACTION, MAXIMUMACTION, parent)
+SieveActionWidgetLister::SieveActionWidgetLister(SieveEditorGraphicalModeWidget *graphicalModeWidget, QWidget *parent)
+    : KPIM::KWidgetLister(false, MINIMUMACTION, MAXIMUMACTION, parent),
+      mSieveGraphicalModeWidget(graphicalModeWidget)
 {
     slotClear();
     updateAddRemoveButton();
@@ -334,7 +336,7 @@ void SieveActionWidgetLister::clearWidget(QWidget *aWidget)
 
 QWidget *SieveActionWidgetLister::createWidget(QWidget *parent)
 {
-    SieveActionWidget *w = new SieveActionWidget(parent);
+    SieveActionWidget *w = new SieveActionWidget(mSieveGraphicalModeWidget, parent);
     reconnectWidget(w);
     return w;
 }
