@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,16 +31,11 @@
 
 using namespace KSieveUi;
 
-SieveConditionHeader::SieveConditionHeader(QObject *parent)
-    : SieveCondition(QStringLiteral("header"), i18n("Header"), parent)
+SieveConditionHeader::SieveConditionHeader(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveCondition(sieveGraphicalModeWidget, QStringLiteral("header"), i18n("Header"), parent)
 {
 }
 
-SieveCondition *SieveConditionHeader::newAction()
-{
-    return new SieveConditionHeader;
-}
-
 QWidget *SieveConditionHeader::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
@@ -48,7 +43,7 @@ QWidget *SieveConditionHeader::createParamWidget(QWidget *parent) const
     lay->setMargin(0);
     w->setLayout(lay);
 
-    SelectMatchTypeComboBox *matchTypeCombo = new SelectMatchTypeComboBox;
+    SelectMatchTypeComboBox *matchTypeCombo = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     matchTypeCombo->setObjectName(QStringLiteral("matchtypecombobox"));
     connect(matchTypeCombo, &SelectMatchTypeComboBox::valueChanged, this, &SieveConditionHeader::valueChanged);
     lay->addWidget(matchTypeCombo);
