@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,16 +29,11 @@
 #include <QDomNode>
 
 using namespace KSieveUi;
-SieveConditionIhave::SieveConditionIhave(QObject *parent)
-    : SieveCondition(QStringLiteral("ihave"), i18n("IHave"), parent)
+SieveConditionIhave::SieveConditionIhave(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveCondition(sieveGraphicalModeWidget, QStringLiteral("ihave"), i18n("IHave"), parent)
 {
 }
 
-SieveCondition *SieveConditionIhave::newAction()
-{
-    return new SieveConditionIhave;
-}
-
 QWidget *SieveConditionIhave::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
