@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -33,15 +33,10 @@
 
 using namespace KSieveUi;
 
-SieveConditionSpamTest::SieveConditionSpamTest(QObject *parent)
-    : SieveCondition(QStringLiteral("spamtest"), i18n("Spam Test"), parent)
+SieveConditionSpamTest::SieveConditionSpamTest(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveCondition(sieveGraphicalModeWidget, QStringLiteral("spamtest"), i18n("Spam Test"), parent)
 {
-    mHasSpamTestPlusSupport = SieveEditorGraphicalModeWidget::sieveCapabilities().contains(QStringLiteral("spamtestplus"));
-}
-
-SieveCondition *SieveConditionSpamTest::newAction()
-{
-    return new SieveConditionSpamTest;
+    mHasSpamTestPlusSupport = sieveCapabilities().contains(QStringLiteral("spamtestplus"));
 }
 
 QWidget *SieveConditionSpamTest::createParamWidget(QWidget *parent) const
@@ -63,7 +58,7 @@ QWidget *SieveConditionSpamTest::createParamWidget(QWidget *parent) const
     relation->setObjectName(QStringLiteral("relation"));
     lay->addWidget(relation);
 
-    SelectComparatorComboBox *comparator = new SelectComparatorComboBox;
+    SelectComparatorComboBox *comparator = new SelectComparatorComboBox(mSieveGraphicalModeWidget);
     connect(comparator, &SelectComparatorComboBox::valueChanged, this, &SieveConditionSpamTest::valueChanged);
     comparator->setObjectName(QStringLiteral("comparator"));
     lay->addWidget(comparator);
