@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -48,7 +48,7 @@ public:
         Zone,
         Weekday
     };
-    explicit SelectDateWidget(QWidget *parent = Q_NULLPTR);
+    explicit SelectDateWidget(QWidget *parent = nullptr);
     ~SelectDateWidget();
 
     QString code() const;
