@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,7 +28,7 @@ class SieveScriptTabWidget : public QTabWidget
 {
     Q_OBJECT
 public:
-    explicit SieveScriptTabWidget(QWidget *parent = Q_NULLPTR);
+    explicit SieveScriptTabWidget(QWidget *parent = nullptr);
     ~SieveScriptTabWidget();
 
 private Q_SLOTS:
