@@ -1,4 +1,4 @@
-/* Copyright (C) 2013-2015 Laurent Montel <montel@kde.org>
+/* Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,23 +20,32 @@
 #define SIEVEEDITORABSTRACTWIDGET_H
 
 #include <QWidget>
+#include "../util/sieveimapaccountsettings.h"
 
 namespace KSieveUi
 {
+class SieveImapAccountSettings;
 class SieveEditorAbstractWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SieveEditorAbstractWidget(QWidget *parent = Q_NULLPTR);
+    explicit SieveEditorAbstractWidget(QWidget *parent = nullptr);
     ~SieveEditorAbstractWidget();
 
     virtual QString currentscript();
     virtual void setImportScript(const QString &);
     void saveAs(const QString &defaultName);
 
+    KSieveUi::SieveImapAccountSettings sieveImapAccountSettings() const;
+
+    void setSieveImapAccountSettings(const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings);
+
 public Q_SLOTS:
     void slotImport();
 
+protected:
+    KSieveUi::SieveImapAccountSettings mSieveImapAccountSettings;
+
 private:
     bool loadFromFile(const QString &filename);
 };
