@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -26,7 +26,7 @@ using namespace KSieveUi;
 
 SieveEditorMenuBar::SieveEditorMenuBar(QWidget *parent)
     : QMenuBar(parent),
-      mTextModeWidget(Q_NULLPTR)
+      mTextModeWidget(nullptr)
 {
     initActions();
     initMenus();
@@ -168,7 +168,6 @@ void SieveEditorMenuBar::slotUpdateActions()
     mZoomResetAction->setEnabled(true);
     mDebugSieveAction->setEnabled(!hasActionInHtmlModeToo);
     mWordWrapAction->setEnabled(!hasActionInHtmlModeToo);
-    //TODO ?
     mPrintAction->setEnabled(!hasActionInHtmlModeToo);
     mPrintPreviewAction->setEnabled(!hasActionInHtmlModeToo);
 }
