@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -57,7 +57,7 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
 {
     QVBoxLayout *lay = new QVBoxLayout;
 #if !defined(NDEBUG)
-    mGenerateXml = 0;
+    mGenerateXml = nullptr;
 #endif
 
     QToolBar *toolbar = new QToolBar;
@@ -92,7 +92,7 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     //Add action to toolBar
 
     toolbar->addAction(mShareScript);
-    SieveEditorMenuBar *menuBar = Q_NULLPTR;
+    SieveEditorMenuBar *menuBar = nullptr;
     if (useMenuBar) {
         menuBar = new SieveEditorMenuBar;
         connect(this, &SieveEditorWidget::changeModeEditor, menuBar, &SieveEditorMenuBar::setEditorMode);
@@ -462,9 +462,9 @@ QString SieveEditorWidget::originalScript() const
     return mOriginalScript;
 }
 
-void SieveEditorWidget::setScript(const QString &script)
+void SieveEditorWidget::setScript(const QString &script, bool clearUndoRedo)
 {
-    mTextModeWidget->setScript(script);
+    mTextModeWidget->setScript(script, clearUndoRedo);
     mOriginalScript = script;
 }
 
@@ -514,6 +514,12 @@ void SieveEditorWidget::setSieveCapabilities(const QStringList &capabilities)
     mGraphicalModeWidget->setSieveCapabilities(capabilities);
 }
 
+void SieveEditorWidget::setSieveImapAccountSettings(const SieveImapAccountSettings &sieveImapAccountSettings)
+{
+    mGraphicalModeWidget->setSieveImapAccountSettings(sieveImapAccountSettings);
+    mTextModeWidget->setSieveImapAccountSettings(sieveImapAccountSettings);
+}
+
 void SieveEditorWidget::slotCreateRulesGraphically()
 {
     switch (mMode) {
