@@ -29,13 +29,14 @@ class QLineEdit;
 class QAction;
 namespace KSieveUi
 {
+class SieveImapAccountSettings;
 class SieveEditorTextModeWidget;
 class SieveEditorGraphicalModeWidget;
 class KSIEVEUI_EXPORT SieveEditorWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SieveEditorWidget(bool useMenuBar, QWidget *parent = Q_NULLPTR);
+    explicit SieveEditorWidget(bool useMenuBar, QWidget *parent = nullptr);
     ~SieveEditorWidget();
     enum EditorMode {
         Unknown = -1,
@@ -46,13 +47,14 @@ public:
     void setReadOnly(bool b);
     QString script() const;
     QString originalScript() const;
-    void setScript(const QString &script);
+    void setScript(const QString &script, bool clearUndoRedo = false);
     void setDebugScript(const QString &debug);
     void setScriptName(const QString &name);
 
     void resultDone();
 
     void setSieveCapabilities(const QStringList &capabilities);
+    void setSieveImapAccountSettings(const SieveImapAccountSettings &sieveImapAccountSettings);
 
     void addFailedMessage(const QString &err);
     void addOkMessage(const QString &msg);
