@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -16,6 +16,7 @@
 */
 
 #include "sieveinfowidget.h"
+#include "util/helper_p.h"
 
 #include <KLocalizedString>
 
@@ -43,7 +44,7 @@ void SieveInfoWidget::setServerInfo(QStringList serverInfos)
 {
     serverInfos.sort();
     QString result = QLatin1String("<qt><b>") + i18n("Sieve server supports:") + QLatin1String("</b><ul>");
-    Q_FOREACH (const QString &info, serverInfos) {
+    for (const QString &info : qAsConst(serverInfos)) {
         result += QLatin1String("<li>") + info;
     }
     result += QLatin1String("</ul></qt>");
