@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -28,7 +28,7 @@ class SieveInfoWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SieveInfoWidget(QWidget *parent = Q_NULLPTR);
+    explicit SieveInfoWidget(QWidget *parent = nullptr);
     ~SieveInfoWidget();
 
     void setServerInfo(QStringList info);
