@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -27,9 +27,9 @@ class KSieveUi::SieveTextEditWidgetPrivate
 {
 public:
     SieveTextEditWidgetPrivate()
-        : mTextEdit(Q_NULLPTR),
-          mSliderContainer(Q_NULLPTR),
-          mFindBar(Q_NULLPTR)
+        : mTextEdit(nullptr),
+          mSliderContainer(nullptr),
+          mFindBar(nullptr)
     {
 
     }
