@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,7 +18,7 @@
 #include "editorsieve_gui.h"
 #include <QDebug>
 #include "ksieveui/editor/sieveeditor.h"
-#include "PimCommon/SieveSyntaxHighlighterUtil"
+#include <PimCommon/SieveSyntaxHighlighterUtil>
 
 #include <qapplication.h>
 #include <QCommandLineParser>
