@@ -1,5 +1,5 @@
 /* Copyright (C) 2010 Torgny Nyblom <nyblom@kde.org>
- * Copyright (C) 2010-2016 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2010-2017 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -18,7 +18,7 @@
  */
 
 #include "findbarbase.h"
-#include "PimCommon/LineEditWithCompleter"
+#include <PimCommon/LineEditWithCompleter>
 
 #include <qicon.h>
 #include <KLocalizedString>
@@ -94,7 +94,7 @@ FindBarBase::FindBarBase(QWidget *parent)
     connect(mSearch, &KLineEdit::textChanged, this, &FindBarBase::autoSearch);
     connect(mSearch, &KLineEdit::clearButtonClicked, this, &FindBarBase::slotClearSearch);
 
-    mStatus = new QLabel;
+    mStatus = new QLabel(this);
     mStatus->setObjectName(QStringLiteral("status"));
     QFontMetrics fm(mStatus->font());
     mNotFoundString = i18n("Phrase not found");
