@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -37,7 +37,7 @@ class KSIEVEUI_EXPORT SieveEditorHelpHtmlWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SieveEditorHelpHtmlWidget(QWidget *parent = Q_NULLPTR);
+    explicit SieveEditorHelpHtmlWidget(QWidget *parent = nullptr);
     ~SieveEditorHelpHtmlWidget();
 
     void openUrl(const QUrl &currentUrl);
