@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -130,6 +130,6 @@ QWebEngineView *SieveEditorWebEngineView::createWindow(QWebEnginePage::WebWindow
 #if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
     return this;
 #else
-    return Q_NULLPTR;
+    return nullptr;
 #endif
 }
