@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -26,7 +26,7 @@ class SieveEditorWebEngineView : public QWebEngineView
 {
     Q_OBJECT
 public:
-    explicit SieveEditorWebEngineView(QWidget *parent = Q_NULLPTR);
+    explicit SieveEditorWebEngineView(QWidget *parent = nullptr);
     ~SieveEditorWebEngineView();
 
 protected:
