@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -24,7 +24,7 @@ class RenameScriptJobTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit RenameScriptJobTest(QObject *parent = Q_NULLPTR);
+    explicit RenameScriptJobTest(QObject *parent = nullptr);
     ~RenameScriptJobTest();
 
 private Q_SLOTS:
