@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,6 +18,7 @@
 #include "generateglobalscriptjob.h"
 
 #include "kmanagesieve/sievejob.h"
+#include "util/helper_p.h"
 
 #include <KLocalizedString>
 
@@ -25,8 +26,8 @@ using namespace KSieveUi;
 GenerateGlobalScriptJob::GenerateGlobalScriptJob(const QUrl &url, QObject *parent)
     : QObject(parent),
       mCurrentUrl(url),
-      mMasterJob(Q_NULLPTR),
-      mUserJob(Q_NULLPTR)
+      mMasterJob(nullptr),
+      mUserJob(nullptr)
 {
 }
 
@@ -40,13 +41,13 @@ void GenerateGlobalScriptJob::kill()
     if (mMasterJob) {
         mMasterJob->kill();
     }
-    mMasterJob = Q_NULLPTR;
+    mMasterJob = nullptr;
 
     if (mUserJob) {
         mUserJob->kill();
-        mUserJob = Q_NULLPTR;
+        mUserJob = nullptr;
     }
-    mUserJob = Q_NULLPTR;
+    mUserJob = nullptr;
 }
 
 void GenerateGlobalScriptJob::addUserActiveScripts(const QStringList &lstScript)
@@ -102,7 +103,7 @@ void GenerateGlobalScriptJob::slotPutMasterResult(KManageSieve::SieveJob *job, b
                           "The server responded:\n%1", job->errorString()));
         return;
     }
-    mMasterJob = Q_NULLPTR;
+    mMasterJob = nullptr;
     writeUserScript();
 }
 
@@ -118,7 +119,7 @@ void GenerateGlobalScriptJob::writeUserScript()
                                         "\n"
                                         "require [\"include\"];\n");
 
-    Q_FOREACH (const QString &activeScript, mListUserActiveScripts) {
+    for (const QString &activeScript : qAsConst(mListUserActiveScripts)) {
         userScript += QStringLiteral("\ninclude :personal \"%1\"").arg(activeScript);
     }
 
@@ -131,7 +132,7 @@ void GenerateGlobalScriptJob::writeUserScript()
 
 void GenerateGlobalScriptJob::slotPutUserResult(KManageSieve::SieveJob *job, bool success)
 {
-    mUserJob = Q_NULLPTR;
+    mUserJob = nullptr;
     if (!success) {
         Q_EMIT error(i18n("Error writing \"User\" script on server.\n"
                           "The server responded:\n%1", job->errorString()));
