@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -21,7 +21,7 @@
 #include <QObject>
 #include <QUrl>
 #include <QStringList>
-#include "ksieveui_export.h"
+#include "ksieveui_private_export.h"
 class QDomDocument;
 class QDomElement;
 namespace KManageSieve
@@ -31,13 +31,13 @@ class SieveJob;
 
 namespace KSieveUi
 {
-class KSIEVEUI_EXPORT ParseUserScriptJob : public QObject
+class KSIEVEUI_TESTS_EXPORT ParseUserScriptJob : public QObject
 {
     Q_OBJECT
 
     friend class ParseUserTest;
 public:
-    explicit ParseUserScriptJob(const QUrl &url, QObject *parent = Q_NULLPTR);
+    explicit ParseUserScriptJob(const QUrl &url, QObject *parent = nullptr);
     ~ParseUserScriptJob();
 
     void start();
