@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -23,6 +23,8 @@
 #include "widgets/sievetreewidgetitem.h"
 #include "managescriptsjob/checkscriptjob.h"
 
+#include "util/sieveimapaccountsettings.h"
+
 #include <KLocalizedString>
 #include <kiconloader.h>
 #include <kwindowsystem.h>
@@ -48,11 +50,11 @@ class KSieveUi::ManageSieveScriptsDialogPrivate
 {
 public:
     ManageSieveScriptsDialogPrivate()
-        : mSieveEditor(Q_NULLPTR),
-          mNewScript(Q_NULLPTR),
-          mEditScript(Q_NULLPTR),
-          mDeleteScript(Q_NULLPTR),
-          mDeactivateScript(Q_NULLPTR),
+        : mSieveEditor(nullptr),
+          mNewScript(nullptr),
+          mEditScript(nullptr),
+          mDeleteScript(nullptr),
+          mDeactivateScript(nullptr),
           mIsNewScript(false),
           mWasActive(false)
     {
@@ -64,6 +66,7 @@ public:
 
     QUrl mCurrentURL;
     QStringList mCurrentCapabilities;
+    KSieveUi::SieveImapAccountSettings mSieveImapAccountSettings;
 
     QPushButton *mNewScript;
     QPushButton *mEditScript;
@@ -161,21 +164,23 @@ void ManageSieveScriptsDialog::slotUpdateButtons(QTreeWidgetItem *item)
     d->mDeactivateScript->setEnabled(desactivateScriptAction);
 }
 
-void ManageSieveScriptsDialog::slotEditScript(const QUrl &url, const QStringList &capabilities)
+void ManageSieveScriptsDialog::slotEditScript(const QUrl &url, const QStringList &capabilities, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings)
 {
     d->mCurrentURL = url;
     d->mCurrentCapabilities = capabilities;
     d->mIsNewScript = false;
+    d->mSieveImapAccountSettings = sieveImapAccountSettings;
     KManageSieve::SieveJob *job = KManageSieve::SieveJob::get(url);
     connect(job, &KManageSieve::SieveJob::result, this, &ManageSieveScriptsDialog::slotGetResult);
 }
 
-void ManageSieveScriptsDialog::slotNewScript(const QUrl &url, const QStringList &capabilities)
+void ManageSieveScriptsDialog::slotNewScript(const QUrl &url, const QStringList &capabilities, const SieveImapAccountSettings &sieveImapAccountSettings)
 {
     d->mCurrentCapabilities = capabilities;
+    d->mSieveImapAccountSettings = sieveImapAccountSettings;
     d->mCurrentURL = url;
     d->mIsNewScript = true;
-    slotGetResult(Q_NULLPTR, true, QString(), false);
+    slotGetResult(nullptr, true, QString(), false);
 }
 
 void ManageSieveScriptsDialog::slotGetResult(KManageSieve::SieveJob *job, bool success, const QString &script, bool isActive)
@@ -194,7 +199,9 @@ void ManageSieveScriptsDialog::slotGetResult(KManageSieve::SieveJob *job, bool s
     d->mSieveEditor = new SieveEditor;
     d->mSieveEditor->setScriptName(d->mCurrentURL.fileName());
     d->mSieveEditor->setSieveCapabilities(d->mCurrentCapabilities);
-    d->mSieveEditor->setScript(script);
+    d->mSieveEditor->setScript(script, true); /*clear undo/redo*/
+    d->mSieveEditor->setSieveImapAccountSettings(d->mSieveImapAccountSettings);
+
     connect(d->mSieveEditor, &SieveEditor::okClicked, this, &ManageSieveScriptsDialog::slotSieveEditorOkClicked);
     connect(d->mSieveEditor, &SieveEditor::cancelClicked, this, &ManageSieveScriptsDialog::slotSieveEditorCancelClicked);
     connect(d->mSieveEditor, &SieveEditor::checkSyntax, this, &ManageSieveScriptsDialog::slotSieveEditorCheckSyntaxClicked);
@@ -236,7 +243,7 @@ void ManageSieveScriptsDialog::slotSieveEditorCancelClicked()
     disableManagerScriptsDialog(false);
     if (d->mSieveEditor) {
         d->mSieveEditor->deleteLater();
-        d->mSieveEditor = Q_NULLPTR;
+        d->mSieveEditor = nullptr;
     }
     d->mCurrentURL = QUrl();
     if (d->mIsNewScript) {
@@ -260,7 +267,7 @@ void ManageSieveScriptsDialog::slotPutResult(KManageSieve::SieveJob *job, bool s
         KMessageBox::information(this, i18n("The Sieve script was successfully uploaded."),
                                  i18n("Sieve Script Upload"));
         d->mSieveEditor->deleteLater();
-        d->mSieveEditor = Q_NULLPTR;
+        d->mSieveEditor = nullptr;
         d->mCurrentURL = QUrl();
     } else {
         KMessageBox::error(this, i18n("Uploading the Sieve script failed.\n"
