@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -40,7 +40,7 @@ class KSIEVEUI_EXPORT ManageSieveScriptsDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit ManageSieveScriptsDialog(QWidget *parent = Q_NULLPTR);
+    explicit ManageSieveScriptsDialog(QWidget *parent = nullptr);
     ~ManageSieveScriptsDialog();
 
 Q_SIGNALS:
@@ -54,8 +54,8 @@ private Q_SLOTS:
     void slotSieveEditorCancelClicked();
     void slotSieveEditorCheckSyntaxClicked();
     void slotUpdateButtons(QTreeWidgetItem *item);
-    void slotEditScript(const QUrl &u, const QStringList &capabilities);
-    void slotNewScript(const QUrl &u, const QStringList &capabilities);    
+    void slotEditScript(const QUrl &u, const QStringList &capabilities, const SieveImapAccountSettings &sieveImapAccountSettings);
+    void slotNewScript(const QUrl &u, const QStringList &capabilities, const SieveImapAccountSettings &sieveImapAccountSettings);
     void slotCheckScriptFinished(const QString &errorMsg, bool success);
 protected:
     void hideEvent(QHideEvent *) Q_DECL_OVERRIDE;
