@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -36,10 +36,9 @@ void XMLPrintingSyntaxHighLighter::init()
     QTextCharFormat testFormat;
     testFormat.setForeground(Qt::gray);
     testFormat.setFontWeight(QFont::Bold);
-    QStringList testType;
-    testType << QStringLiteral("require");
+    const QStringList testType = { QStringLiteral("require") };
 
-    Q_FOREACH (const QString &s, testType) {
+    for (const QString &s : testType) {
         const QRegularExpression regex(s, QRegularExpression::CaseInsensitiveOption);
         m_rules.append(KPIMTextEdit::Rule(regex, testFormat));
     }
@@ -47,9 +46,8 @@ void XMLPrintingSyntaxHighLighter::init()
     QTextCharFormat quoteFormat;
     quoteFormat.setForeground(Qt::blue);
     quoteFormat.setFontWeight(QFont::Bold);
-    QStringList quoteType;
-    quoteType << QStringLiteral("quoted") << QStringLiteral("hash") << QStringLiteral("bracket") << QStringLiteral("multiline");
-    Q_FOREACH (const QString &s, quoteType) {
+    const QStringList quoteType = { QStringLiteral("quoted"), QStringLiteral("hash"), QStringLiteral("bracket"), QStringLiteral("multiline")};
+    for (const QString &s : quoteType) {
         const QRegularExpression regex(s, QRegularExpression::CaseInsensitiveOption);
         m_rules.append(KPIMTextEdit::Rule(regex, quoteFormat));
     }
@@ -57,10 +55,10 @@ void XMLPrintingSyntaxHighLighter::init()
     QTextCharFormat misc;
     misc.setForeground(Qt::red);
     misc.setFontWeight(QFont::Bold);
-    QStringList miscType;
-    miscType << QStringLiteral("control") << QStringLiteral("block") << QStringLiteral("script") << QStringLiteral("action") << QStringLiteral("comment");
-    miscType << QStringLiteral("num") << QStringLiteral("tag") << QStringLiteral("list") << QStringLiteral("str") << QStringLiteral("test") << QStringLiteral("crlf/");
-    Q_FOREACH (const QString &s, miscType) {
+    const QStringList miscType = QStringList()
+                                 << QStringLiteral("control") << QStringLiteral("block") << QStringLiteral("script") << QStringLiteral("action") << QStringLiteral("comment")
+                                 << QStringLiteral("num") << QStringLiteral("tag") << QStringLiteral("list") << QStringLiteral("str") << QStringLiteral("test") << QStringLiteral("crlf/");
+    for (const QString &s : miscType) {
         const QRegularExpression regex(s, QRegularExpression::CaseInsensitiveOption);
         m_rules.append(KPIMTextEdit::Rule(regex, misc));
     }
