@@ -21,7 +21,7 @@
 #define SIEVESCRIPTDEBUGGERFRONTENDWIDGET_H
 
 #include <QWidget>
-#include "ksieveui_export.h"
+#include "ksieveui_private_export.h"
 
 namespace KPIMTextEdit
 {
@@ -36,11 +36,11 @@ namespace KSieveUi
 {
 class SieveTextEditWidget;
 class SieveScriptDebuggerWarning;
-class KSIEVEUI_EXPORT SieveScriptDebuggerFrontEndWidget : public QWidget
+class KSIEVEUI_TESTS_EXPORT SieveScriptDebuggerFrontEndWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SieveScriptDebuggerFrontEndWidget(QWidget *parent = Q_NULLPTR);
+    explicit SieveScriptDebuggerFrontEndWidget(QWidget *parent = nullptr);
     ~SieveScriptDebuggerFrontEndWidget();
 
     QString script() const;
