@@ -21,14 +21,14 @@
 #define SIEVESCRIPTDEBUGGERWARNING_H
 
 #include <KMessageWidget>
-#include "ksieveui_export.h"
+#include "ksieveui_private_export.h"
 namespace KSieveUi
 {
-class KSIEVEUI_EXPORT SieveScriptDebuggerWarning : public KMessageWidget
+class KSIEVEUI_TESTS_EXPORT SieveScriptDebuggerWarning : public KMessageWidget
 {
     Q_OBJECT
 public:
-    explicit SieveScriptDebuggerWarning(QWidget *parent = Q_NULLPTR);
+    explicit SieveScriptDebuggerWarning(QWidget *parent = nullptr);
     ~SieveScriptDebuggerWarning();
 
     void setErrorMessage(const QString &msg);
