@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,7 +25,7 @@ class VacationDialogTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit VacationDialogTest(QObject *parent = Q_NULLPTR);
+    explicit VacationDialogTest(QObject *parent = nullptr);
     ~VacationDialogTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
