@@ -209,7 +209,7 @@ void VacationUtilsTest::testParseScriptComplexTime()
 void VacationUtilsTest::testWriteScript()
 {
     VacationUtils::Vacation vacation, vacationA;
-    QStringList aliases = QStringList() << QStringLiteral("test@test.de");
+    const QStringList aliases = QStringList() << QStringLiteral("test@test.de");
     vacation.valid = true;
 
     vacation.messageText = QStringLiteral("dsfgsdfgsdfg");
@@ -221,7 +221,7 @@ void VacationUtilsTest::testWriteScript()
     vacation.endDate = QDate(2015, 03, 04);
     vacation.active = true;
 
-    foreach (const QString &alias, aliases) {
+    for (const QString &alias : aliases) {
         KMime::Types::Mailbox a;
         a.fromUnicodeString(alias);
         vacation.aliases.append(a.addrSpec());
@@ -311,7 +311,7 @@ void VacationUtilsTest::testUpdateVacationBlock()
     }
 
     QStringList vacation;
-    vacation.reserve(linesA.count()-5);
+    vacation.reserve(linesA.count() - 5);
     for (int i = 5; i < linesA.count(); ++i) {
         vacation.append(linesA.at(i));
     }
@@ -322,12 +322,12 @@ void VacationUtilsTest::testUpdateVacationBlock()
     QCOMPARE(VacationUtils::updateVacationBlock(scriptB, scriptA), scriptA);
     QCOMPARE(VacationUtils::updateVacationBlock(scriptAattend, scriptB), scriptBattend);
     QCOMPARE(VacationUtils::updateVacationBlock(scriptBattend, scriptA), scriptAattend);
-    QCOMPARE(VacationUtils::updateVacationBlock(scriptA, attend), header.join(QStringLiteral("\n")));
+    QCOMPARE(VacationUtils::updateVacationBlock(scriptA, attend), header.join(QLatin1Char('\n')));
     QStringList output = vacation;
     output << attend;
-    QCOMPARE(VacationUtils::updateVacationBlock(attend, scriptA), output.join(QStringLiteral("\n")));
+    QCOMPARE(VacationUtils::updateVacationBlock(attend, scriptA), output.join(QLatin1Char('\n')));
     output.insert(0, require);
-    QCOMPARE(VacationUtils::updateVacationBlock(require + QStringLiteral("\n") + attend, scriptA), output.join(QStringLiteral("\n")));
+    QCOMPARE(VacationUtils::updateVacationBlock(require + QStringLiteral("\n") + attend, scriptA), output.join(QLatin1Char('\n')));
 }
 
 void VacationUtilsTest::testMergeRequireLine()
