@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -24,8 +24,6 @@ See README for further information.
 #include "vacationutils.h"
 #include "vacationscriptextractor.h"
 #include "sieve-vacation.h"
-#include <KIdentityManagement/IdentityManager>
-#include <KIdentityManagement/Identity>
 
 #include <KLocalizedString>
 #include <QDate>
@@ -88,7 +86,8 @@ bool Legacy::VacationUtils::parseScript(const QString &script, QString &messageT
     }
     notificationInterval = vdx.notificationInterval();
     aliases.clear();
-    foreach (const QString &alias, vdx.aliases()) {
+    const QStringList lstAliases = vdx.aliases();
+    for (const QString &alias : lstAliases) {
         KMime::Types::Mailbox a;
         a.fromUnicodeString(alias);
         aliases.append(a.addrSpec());
