@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,7 +18,8 @@
 #include "vacationcheckjob.h"
 #include "vacationutils.h"
 #include "managescriptsjob/parseuserscriptjob.h"
-#include "util/util.h"
+#include "util/helper_p.h"
+#include "util/util_p.h"
 
 #include <kmanagesieve/sievejob.h>
 
@@ -32,8 +33,8 @@ VacationCheckJob::VacationCheckJob(const QUrl &url, const QString &serverName, Q
     : QObject(parent),
       mServerName(serverName),
       mUrl(url)
-    , mSieveJob(Q_NULLPTR)
-    , mParseJob(Q_NULLPTR)
+    , mSieveJob(nullptr)
+    , mParseJob(nullptr)
     , mScriptPos(-1)
     , mKep14Support(false)
     , mNoScriptFound(false)
@@ -50,12 +51,12 @@ void VacationCheckJob::kill()
     if (mSieveJob) {
         mSieveJob->kill();
     }
-    mSieveJob = Q_NULLPTR;
+    mSieveJob = nullptr;
 
     if (mParseJob) {
         mParseJob->kill();
     }
-    mParseJob = Q_NULLPTR;
+    mParseJob = nullptr;
 }
 
 void VacationCheckJob::setKep14Support(bool kep14Support)
@@ -69,7 +70,7 @@ void VacationCheckJob::start()
         QUrl url = mUrl;
         url = url.adjusted(QUrl::RemoveFilename);
         url.setPath(url.path() + QLatin1String("USER"));
-        mParseJob = new ParseUserScriptJob(url);
+        mParseJob = new ParseUserScriptJob(url, this);
         connect(mParseJob, &ParseUserScriptJob::finished, this, &VacationCheckJob::slotGotActiveScripts);
         mParseJob->start();
         mSieveJob = KManageSieve::SieveJob::list(url);
@@ -85,7 +86,7 @@ void VacationCheckJob::slotGetResult(KManageSieve::SieveJob *job, bool success,
     Q_ASSERT(job == mSieveJob);
     mScript = script;
     mSieveCapabilities = mSieveJob->sieveCapabilities();
-    mSieveJob = Q_NULLPTR;
+    mSieveJob = nullptr;
 
     if (mKep14Support) {
         VacationUtils::Vacation vacation = VacationUtils::parseScript(script);
@@ -119,7 +120,7 @@ void VacationCheckJob::slotGetResult(KManageSieve::SieveJob *job, bool success,
 void VacationCheckJob::slotGotActiveScripts(ParseUserScriptJob *job)
 {
     Q_ASSERT(job == mParseJob);
-    mParseJob = Q_NULLPTR;
+    mParseJob = nullptr;
     if (!job->error().isEmpty()) {
         emitError(i18n("ParseUserScriptJob failed: %1", job->error()));
         return;
@@ -135,7 +136,7 @@ void VacationCheckJob::slotGotList(KManageSieve::SieveJob *job, bool success, co
 {
     Q_UNUSED(activeScript)
     Q_ASSERT(job == mSieveJob);
-    mSieveJob = Q_NULLPTR;
+    mSieveJob = nullptr;
     if (!success) {
         emitError(i18n("Failed to get the list of Sieve scripts.\n"
                        "The server responded:\n%1", job->errorString()));
@@ -152,7 +153,7 @@ void VacationCheckJob::slotGotList(KManageSieve::SieveJob *job, bool success, co
 void VacationCheckJob::emitError(const QString &errorMessage)
 {
     qCWarning(LIBKSIEVE_LOG) << errorMessage;
-    //TODO: Q_EMIT error
+    Q_EMIT error(errorMessage);
 }
 
 void VacationCheckJob::searchVacationScript()
@@ -160,7 +161,7 @@ void VacationCheckJob::searchVacationScript()
     QStringList scriptList = mActiveScripts;
 
     // Reorder script list
-    foreach (const QString &script, mAvailableScripts) {
+    for (const QString &script : qAsConst(mAvailableScripts)) {
         if (!scriptList.contains(script)) {
             scriptList.append(script);
         }
@@ -178,6 +179,7 @@ void VacationCheckJob::getNextScript()
         mNoScriptFound = true;
         Q_EMIT scriptActive(this, QString(), false);
         qCDebug(LIBKSIEVE_LOG) << "no vacation script found :(";
+        return;
     }
     QUrl url = mUrl;
     url = url.adjusted(QUrl::RemoveFilename);
