@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -24,8 +24,6 @@
 #include <managescriptsjob/parseuserscriptjob.h>
 #include "sieve-vacation.h"
 
-#include <kmime/kmime_header_parsing.h>
-
 #include <kmanagesieve/sievejob.h>
 
 #include "libksieve_debug.h"
@@ -40,12 +38,12 @@
 using namespace KSieveUi;
 VacationPageWidget::VacationPageWidget(QWidget *parent)
     : QWidget(parent),
-      mVacationManager(Q_NULLPTR),
+      mVacationManager(nullptr),
       mPageScript(Script),
       mWasActive(false),
       mHasDateSupport(false)
 {
-    QVBoxLayout *lay = new QVBoxLayout;
+    QVBoxLayout *lay = new QVBoxLayout(this);
     lay->setMargin(0);
     mStackWidget = new QStackedWidget;
     lay->addWidget(mStackWidget);
@@ -80,7 +78,6 @@ VacationPageWidget::VacationPageWidget(QWidget *parent)
     mStackWidget->addWidget(w);
 
     mStackWidget->setCurrentIndex(Script);
-    setLayout(lay);
 }
 
 VacationPageWidget::~VacationPageWidget()
@@ -186,7 +183,7 @@ KSieveUi::VacationCreateScriptJob *VacationPageWidget::writeScript()
         createJob->setScript(script);
         return createJob;
     }
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 void VacationPageWidget::setDefault()
