@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,7 +18,7 @@
 #ifndef MANAGESIEVETREEVIEW_H
 #define MANAGESIEVETREEVIEW_H
 
-#include "PimCommon/CustomTreeView"
+#include <PimCommon/CustomTreeView>
 #include "ksieveui_export.h"
 
 namespace KSieveUi
@@ -27,7 +27,7 @@ class KSIEVEUI_EXPORT ManageSieveTreeView : public PimCommon::CustomTreeView
 {
     Q_OBJECT
 public:
-    explicit ManageSieveTreeView(QWidget *parent = Q_NULLPTR);
+    explicit ManageSieveTreeView(QWidget *parent = nullptr);
     ~ManageSieveTreeView();
 
     void setNoImapFound(bool found);
