@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -25,7 +25,10 @@
 #include <managescriptsjob/parseuserscriptjob.h>
 #include <managescriptsjob/generateglobalscriptjob.h>
 #include <PimCommon/NetworkManager>
-#include <util/util.h>
+#include "util/helper_p.h"
+#include "util/util_p.h"
+
+#include <KSieveUi/SieveImapAccountSettings>
 
 #include <QInputDialog>
 #include <KStandardGuiItem>
@@ -45,7 +48,7 @@ class KSieveUi::ManageSieveWidgetPrivate
 {
 public:
     ManageSieveWidgetPrivate()
-        : mTreeView(Q_NULLPTR),
+        : mTreeView(nullptr),
           mClearAll(false),
           mBlockSignal(false)
 
@@ -170,9 +173,10 @@ void ManageSieveWidget::slotContextMenuRequested(const QPoint &p)
         }
     } else if (!item->parent()) {
         // top-levels:
-        if (!serverHasError(item) && mJobs.keys(item).isEmpty()) {
+        const bool jobsListIsEmpty = mJobs.keys(item).isEmpty();
+        if (!serverHasError(item) && jobsListIsEmpty) {
             menu.addAction(QIcon::fromTheme(QStringLiteral("document-new")), i18n("New Script..."), this, &ManageSieveWidget::slotNewScript);
-        } else if (!mJobs.keys(item).isEmpty()) { //In Progress
+        } else if (!jobsListIsEmpty) { //In Progress
             menu.addAction(KStandardGuiItem::cancel().icon(), KStandardGuiItem::cancel().text(), this, &ManageSieveWidget::slotCancelFetch);
         }
     }
@@ -185,8 +189,8 @@ void ManageSieveWidget::slotCancelFetch()
 {
     QTreeWidgetItem *item = d->mTreeView->currentItem();
     if (item) {
-        const QList<KManageSieve::SieveJob *>jobs = mJobs.keys(item);
-        Q_FOREACH (KManageSieve::SieveJob *job, jobs) {
+        const QList<KManageSieve::SieveJob *> jobs = mJobs.keys(item);
+        for (KManageSieve::SieveJob *job : jobs) {
             job->kill();
         }
     }
@@ -215,10 +219,11 @@ void ManageSieveWidget::slotNewScript()
     }
 
     bool ok = false;
-    const QString name = QInputDialog::getText(this, i18n("New Sieve Script"),
-                         i18n("Please enter a name for the new Sieve script:"), QLineEdit::Normal,
-                         i18n("unnamed"), &ok);
-    if (!ok || name.trimmed().isEmpty()) {
+    QString name = QInputDialog::getText(this, i18n("New Sieve Script"),
+                                         i18n("Please enter a name for the new Sieve script:"), QLineEdit::Normal,
+                                         i18n("unnamed"), &ok);
+    name = name.trimmed();
+    if (!ok || name.isEmpty()) {
         return;
     }
 
@@ -245,6 +250,7 @@ void ManageSieveWidget::slotNewScript()
     }
 
     const QStringList currentCapabilities = currentItem->data(0, SIEVE_SERVER_CAPABILITIES).toStringList();
+    const KSieveUi::SieveImapAccountSettings sieveimapaccountsettings = currentItem->data(0, SIEVE_SERVER_IMAP_SETTINGS).value<KSieveUi::SieveImapAccountSettings>();
 
     d->mBlockSignal = true;
     QTreeWidgetItem *newItem = new QTreeWidgetItem(currentItem);
@@ -252,7 +258,7 @@ void ManageSieveWidget::slotNewScript()
     newItem->setText(0, name);
     newItem->setCheckState(0, Qt::Unchecked);
     d->mBlockSignal = false;
-    Q_EMIT newScript(u, currentCapabilities);
+    Q_EMIT newScript(u, currentCapabilities, sieveimapaccountsettings);
 }
 
 void ManageSieveWidget::slotEditScript()
@@ -271,8 +277,9 @@ void ManageSieveWidget::slotEditScript()
     }
     url = url.adjusted(QUrl::RemoveFilename);
     url.setPath(url.path() +  QLatin1Char('/') + currentItem->text(0));
+    const KSieveUi::SieveImapAccountSettings sieveimapaccountsettings = parent->data(0, SIEVE_SERVER_IMAP_SETTINGS).value<KSieveUi::SieveImapAccountSettings>();
     const QStringList currentCapabilities = parent->data(0, SIEVE_SERVER_CAPABILITIES).toStringList();
-    Q_EMIT editScript(url, currentCapabilities);
+    Q_EMIT editScript(url, currentCapabilities, sieveimapaccountsettings);
 }
 
 void ManageSieveWidget::slotDeactivateScript()
@@ -506,7 +513,7 @@ void ManageSieveWidget::slotGotList(KManageSieve::SieveJob *job, bool success, c
     }
 
     d->mBlockSignal = true; // don't trigger slotItemChanged
-    Q_FOREACH (const QString &script, listScript) {
+    for (const QString &script : listScript) {
         //Hide protected name.
         if (Util::isKep14ProtectedName(script)) {
             continue;
@@ -523,7 +530,6 @@ void ManageSieveWidget::slotGotList(KManageSieve::SieveJob *job, bool success, c
     }
     d->mBlockSignal = false;
 
-    qCDebug(LIBKSIEVE_LOG) << " LOAD";
     const bool hasKep14EditorMode = Util::hasKep14Support(job->sieveCapabilities(), listScript, activeScript);
     if (hasKep14EditorMode) {
         QUrl u = mUrls[parent];
@@ -539,6 +545,7 @@ void ManageSieveWidget::slotGotList(KManageSieve::SieveJob *job, bool success, c
     parent->setData(0, SIEVE_SERVER_CAPABILITIES, job->sieveCapabilities());
     parent->setData(0, SIEVE_SERVER_ERROR, false);
     parent->setData(0, SIEVE_SERVER_MODE, hasKep14EditorMode ? Kep14EditorMode : NormalEditorMode);
+    parent->setData(0, SIEVE_SERVER_IMAP_SETTINGS, QVariant::fromValue(job->property("sieveimapaccountsettings").value<KSieveUi::SieveImapAccountSettings>()));
     d->mTreeView->expandItem(parent);
 }
 
@@ -571,7 +578,7 @@ void ManageSieveWidget::setActiveScripts(ParseUserScriptJob *job)
         }
     }
 
-    foreach (const QString &scriptName, scriptOrder) {
+    for (const QString &scriptName : qAsConst(scriptOrder)) {
         parent->addChild(scriptMap[scriptName]);
     }
 
