@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -66,7 +66,7 @@ class KSieveUi::SieveTreeWidgetItemPrivate
 {
 public:
     SieveTreeWidgetItemPrivate()
-        : mProgress(Q_NULLPTR)
+        : mProgress(nullptr)
     {
 
     }
