@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -50,7 +50,7 @@ class SieveTreeWidgetProgress : public QObject
 {
     Q_OBJECT
 public:
-    explicit SieveTreeWidgetProgress(SieveTreeWidgetItem *item, QObject *parent = Q_NULLPTR);
+    explicit SieveTreeWidgetProgress(SieveTreeWidgetItem *item, QObject *parent = nullptr);
     ~SieveTreeWidgetProgress();
 
     void startAnimation();
